@@ -128,12 +128,12 @@ load_file_list (GeditWindow         *window,
 		gint                 column_pos,
 		gboolean             create)
 {
-	GeditTab      *tab;
-	GSList        *loaded_files = NULL; /* Number of files to load */
-	gboolean       jump_to = TRUE; /* Whether to jump to the new tab */
-	GList         *win_docs;
-	GSList        *files_to_load = NULL;
-	const GSList  *l;
+	GeditTab *tab;
+	GSList *loaded_files = NULL; /* Number of files to load */
+	gboolean jump_to = TRUE; /* Whether to jump to the new tab */
+	GList *win_docs;
+	GSList *files_to_load = NULL;
+	const GSList *l;
 	gint num_loaded_files = 0;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -144,45 +144,47 @@ load_file_list (GeditWindow         *window,
 	 * in "window" and remove duplicates from "uris" list */
 	for (l = files; l != NULL; l = l->next)
 	{
-		if (!is_duplicated_file (files_to_load, l->data))
+		if (is_duplicated_file (files_to_load, l->data))
 		{
-			tab = get_tab_from_file (win_docs, l->data);
-			if (tab != NULL)
+			continue;
+		}
+
+		tab = get_tab_from_file (win_docs, l->data);
+		if (tab != NULL)
+		{
+			if (l == files)
 			{
-				if (l == files)
+				GeditDocument *doc;
+
+				gedit_window_set_active_tab (window, tab);
+				jump_to = FALSE;
+				doc = gedit_tab_get_document (tab);
+
+				if (line_pos > 0)
 				{
-					GeditDocument *doc;
-
-					gedit_window_set_active_tab (window, tab);
-					jump_to = FALSE;
-					doc = gedit_tab_get_document (tab);
-
-					if (line_pos > 0)
+					if (column_pos > 0)
 					{
-						if (column_pos > 0)
-						{
-							gedit_document_goto_line_offset (doc,
-							                                 line_pos - 1,
-							                                 column_pos - 1);
-						}
-						else
-						{
-							gedit_document_goto_line (doc, line_pos - 1);
-						}
-
-						gedit_view_scroll_to_cursor (gedit_tab_get_view (tab));
+						gedit_document_goto_line_offset (doc,
+						                                 line_pos - 1,
+						                                 column_pos - 1);
+					}
+					else
+					{
+						gedit_document_goto_line (doc, line_pos - 1);
 					}
-				}
 
-				++num_loaded_files;
-				loaded_files = g_slist_prepend (loaded_files,
-				                                gedit_tab_get_document (tab));
-			}
-			else
-			{
-				files_to_load = g_slist_prepend (files_to_load, 
-								 l->data);
+					gedit_view_scroll_to_cursor (gedit_tab_get_view (tab));
+				}
 			}
+
+			++num_loaded_files;
+			loaded_files = g_slist_prepend (loaded_files,
+			                                gedit_tab_get_document (tab));
+		}
+		else
+		{
+			files_to_load = g_slist_prepend (files_to_load,
+							 l->data);
 		}
 	}
 
@@ -1015,8 +1017,7 @@ _gedit_cmd_file_save_documents_list (GeditWindow *window,
 	gedit_debug (DEBUG_COMMANDS);
 
 	g_return_if_fail (!(gedit_window_get_state (window) & 
-			    (GEDIT_WINDOW_STATE_PRINTING |
-			     GEDIT_WINDOW_STATE_SAVING_SESSION)));
+			    GEDIT_WINDOW_STATE_PRINTING));
 
 	l = docs;
 	while (l != NULL)
@@ -1334,7 +1335,7 @@ _gedit_cmd_file_revert (GtkAction   *action,
 	 * if the document has not been modified, do
 	 * not bug the user further */
 	if (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION ||
-	    _gedit_tab_can_close (tab))
+	    _gedit_tab_get_can_close (tab))
 	{
 		do_revert (window, tab);
 		return;
@@ -1765,14 +1766,11 @@ tab_can_close (GeditTab  *tab,
 
 	doc = gedit_tab_get_document (tab);
 
-	if (!_gedit_tab_can_close (tab))
+	if (!_gedit_tab_get_can_close (tab))
 	{
-		GtkWidget     *dlg;
-
-		dlg = gedit_close_confirmation_dialog_new_single (window,
-								  doc,
-								  FALSE);
+		GtkWidget *dlg;
 
+		dlg = gedit_close_confirmation_dialog_new_single (window, doc);
 		g_signal_connect (dlg,
 				  "response",
 				  G_CALLBACK (close_confirmation_dialog_response_handler),
@@ -1851,8 +1849,7 @@ file_close_all (GeditWindow *window,
 
 	g_return_if_fail (!(gedit_window_get_state (window) &
 	                    (GEDIT_WINDOW_STATE_SAVING |
-	                     GEDIT_WINDOW_STATE_PRINTING |
-	                     GEDIT_WINDOW_STATE_SAVING_SESSION)));
+	                     GEDIT_WINDOW_STATE_PRINTING)));
 
 	g_object_set_data (G_OBJECT (window),
 			   GEDIT_IS_CLOSING_ALL,
@@ -1890,14 +1887,12 @@ file_close_all (GeditWindow *window,
 
 		dlg = gedit_close_confirmation_dialog_new_single (
 						GTK_WINDOW (window),
-						doc,
-						FALSE);
+						doc);
 	}
 	else
 	{
 		dlg = gedit_close_confirmation_dialog_new (GTK_WINDOW (window),
-							   unsaved_docs,
-							   FALSE);
+							   unsaved_docs);
 	}
 
 	g_list_free (unsaved_docs);
@@ -1918,8 +1913,7 @@ _gedit_cmd_file_close_all (GtkAction   *action,
 
 	g_return_if_fail (!(gedit_window_get_state (window) &
 	                    (GEDIT_WINDOW_STATE_SAVING |
-	                    GEDIT_WINDOW_STATE_PRINTING |
-	                    GEDIT_WINDOW_STATE_SAVING_SESSION)));
+	                    GEDIT_WINDOW_STATE_PRINTING)));
 
 	file_close_all (window, FALSE);
 }
@@ -1933,8 +1927,8 @@ quit_all ()
 	GList *item;
 	GeditApp *app;
 
-	app = gedit_app_get_default ();
-	windows = g_list_copy ((GList *)gedit_app_get_windows (app));
+	app = GEDIT_APP (g_application_get_default ());
+	windows = g_list_copy (gtk_application_get_windows (GTK_APPLICATION (app)));
 
 	for (item = windows; item; item = g_list_next (item))
 	{
@@ -1946,8 +1940,7 @@ quit_all ()
 
 		if (!(gedit_window_get_state (window) &
 		                    (GEDIT_WINDOW_STATE_SAVING |
-		                     GEDIT_WINDOW_STATE_PRINTING |
-		                     GEDIT_WINDOW_STATE_SAVING_SESSION)))
+		                     GEDIT_WINDOW_STATE_PRINTING)))
 		{
 			file_close_all (window, TRUE);
 		}
@@ -1973,8 +1966,7 @@ _gedit_cmd_file_quit (GtkAction   *action,
 
 	g_return_if_fail (!(gedit_window_get_state (window) &
 	                    (GEDIT_WINDOW_STATE_SAVING |
-	                     GEDIT_WINDOW_STATE_PRINTING |
-	                     GEDIT_WINDOW_STATE_SAVING_SESSION)));
+	                     GEDIT_WINDOW_STATE_PRINTING)));
 
 	file_close_all (window, TRUE);
 }
